# PipAssimp

Fork of [PyAssimp](https://pypi.org/project/pyassimp/) that includes a minified build of the the [assimp](https://github.com/assimp/assimp) library. This is still a large package (~68mb), but half the size of the full assimp build. Also working model can be installed from requirments.txt, which saves some hassle on continous pipelines.

##### [https://pypi.org/project/PipAssimp](https://pypi.org/project/PipAssimp/)

## Installation
```  sh
$ pip install PipAssimp
```


## Supported Imports

| String Code   | Extension |
| ------        | ------    |
| 'obj'         | .obj      |
| '3ds'         | .3ds      |
| 'assbin'      | .assbin   |
| 'collada'     | .dae      |
| 'ply'         | .ply      |
| 'stl'         | .stl      |
| 'stlb'        | .stl      |
| 'stp'         | .stp      |
| 'glb2'        | .glb      |
| 'glb'         | .glb      |
| 'gltf2'       | .gltf     |
| 'gltf'        | .gltf     |
| 'blend'       | .blend    |


## Supported Exports

| String Code   | Extension |
| ------        | ------    |
| 'obj'         | .obj      |
| '3ds'         | .3ds      |
| 'assbin'      | .assbin   |
| 'collada'     | .dae      |
| 'ply'         | .ply      |
| 'stl'         | .stl      |
| 'stlb'        | .stl      |
| 'stp'         | .stp      |
| 'glb2'        | .glb      |
| 'glb'         | .gltf     |
| 'gltf2'       | .gltf     |
| 'gltf'        | .gltf     |